@@ -51,8 +51,9 @@ LC_DEVICE_BUSTYPE LC_Device_BusType_fromString(const char *s) {
     return LC_Device_BusType_Any;
   else if (strcasecmp(s, "UsbRaw")==0)
     return LC_Device_BusType_UsbRaw;
-  else if (strcasecmp(s, "UsbTty")==0)
-    return LC_Device_BusType_UsbTty;
+  else if ((strcasecmp(s, "UsbTty")==0) ||
+	   (strcasecmp(s, "tty")==0))
+    return LC_Device_BusType_Tty;
   else if (strcasecmp(s, "pci")==0)
     return LC_Device_BusType_Pci;
   else if (strcasecmp(s, "pcmcia")==0)
@@ -68,7 +69,7 @@ const char *LC_Device_BusType_toString(LC_DEVICE_BUSTYPE i) {
   switch(i) {
   case LC_Device_BusType_Any:    return "any";
   case LC_Device_BusType_UsbRaw: return "UsbRaw";
-  case LC_Device_BusType_UsbTty: return "UsbTty";
+  case LC_Device_BusType_Tty:    return "tty";
   case LC_Device_BusType_Pci:    return "pci";
   case LC_Device_BusType_Pcmcia: return "pcmcia";
   case LC_Device_BusType_Serial: return "serial";
@@ -109,6 +110,7 @@ void LC_Device_free(LC_DEVICE *ud) {
     free(ud->path);
     free(ud->deviceName);
     free(ud->busName);
+    free(ud->halPath);
     GWEN_FREE_OBJECT(ud);
     DBG_MEM_DEC("LC_DEVICE");
   }
@@ -138,6 +140,8 @@ LC_DEVICE *LC_Device_dup(const LC_DEVICE *od) {
     ud->readerType=strdup(od->readerType);
   if (od->driverType)
     ud->driverType=strdup(od->driverType);
+  if (od->halPath)
+    ud->halPath=strdup(od->halPath);
 
   return ud;
 }
@@ -274,6 +278,22 @@ void LC_Device_SetReaderType(LC_DEVICE *ud, const char *s) {
 
 
 
+const char *LC_Device_GetHalPath(const LC_DEVICE *ud) {
+  assert(ud);
+  return ud->halPath;
+}
+
+
+
+void LC_Device_SetHalPath(LC_DEVICE *ud, const char *s) {
+  assert(ud);
+  free(ud->halPath);
+  if (s) ud->halPath=strdup(s);
+  else ud->halPath=NULL;
+}
+
+
+
 LC_DEVICE *LC_Device_List_Find(LC_DEVICE_LIST *dl,
                                LC_DEVICE_BUSTYPE busType,
                                uint32_t busId,
@@ -457,6 +477,10 @@ int LC_Device_ReplaceVars(const LC_DEVICE *d, const char *tmpl,
           if (d->driverType)
             GWEN_Buffer_AppendString(buf, d->driverType);
         }
+	else if (strcasecmp(vname, "halpath")==0) {
+	  if (d->halPath)
+	    GWEN_Buffer_AppendString(buf, d->halPath);
+	}
         else {
           DBG_ERROR(0, "Bad replace string (unknown var \"%s\" in \"%s\")",
                     vname, tmpl);
@@ -531,6 +555,8 @@ void LC_DevScanner_SetReadDevsFn(LC_DEVSCANNER *um,
 
 
 
+
+
 LC_DEVMONITOR *LC_DevMonitor_new() {
   LC_DEVMONITOR *um;
 
@@ -609,7 +635,7 @@ int LC_DevMonitor_Scan(LC_DEVMONITOR *um) {
                 d->busId,
                 d->deviceId,
                 d->vendorId,
-                d->productId);
+		d->productId);
       newd=LC_Device_dup(d);
       newd->devicePos=d->devicePos;
       LC_Device_List_Add(newd, um->newDevices);
@@ -697,3 +723,4 @@ void LC_DevMonitor_AddScanner(LC_DEVMONITOR *um, LC_DEVSCANNER *sc) {
 
 
 
+
