@@ -11,8 +11,8 @@
  ***************************************************************************/
 
 
-#ifndef CHIPCARD_SERVER_USBMONITOR_P_H
-#define CHIPCARD_SERVER_USBMONITOR_P_H
+#ifndef CHIPCARD_SERVER_USBRAWSCANNER_P_H
+#define CHIPCARD_SERVER_USBRAWSCANNER_P_H
 
 #include "usbrawscanner_l.h"
 
@@ -21,4 +21,4 @@ static
 int LC_UsbRawScanner_ReadDevs(LC_DEVSCANNER *sc, LC_DEVICE_LIST *dl);
 
 
-#endif /* CHIPCARD_SERVER_USBMONITOR_P_H */
+#endif /* CHIPCARD_SERVER_USBRAWSCANNER_P_H */
